@@ -18,15 +18,18 @@ from mycli.packages.special.iocommands import (
     is_expanded_output,
     is_pager_enabled,
     is_redirected,
+    is_show_favorite_query,
     is_timing_enabled,
     open_external_editor,
     set_delimiter,
+    set_destructive_keywords,
     set_expanded_output,
     set_favorite_queries,
     set_forced_horizontal_output,
     set_pager,
     set_pager_enabled,
     set_redirect,
+    set_show_favorite_query,
     set_timing_enabled,
     split_queries,
     unset_once_if_written,
@@ -75,6 +78,7 @@ __all__: list[str] = [
     'parse_special_command',
     'register_special_command',
     'set_delimiter',
+    'set_destructive_keywords',
     'set_expanded_output',
     'set_favorite_queries',
     'set_forced_horizontal_output',
@@ -82,6 +86,8 @@ __all__: list[str] = [
     'set_pager_enabled',
     'set_redirect',
     'set_timing_enabled',
+    'set_show_favorite_query',
+    'is_show_favorite_query',
     'special_command',
     'split_queries',
     'sql_using_llm',
